#!/bin/sh
#
# (c) 2000 Sun Microsystems, Inc.
#

#
# Interface script for the QS qsub command
#
# This shell script gets started by cod_qstd to
# pass a job into another queueing system
#
# $1 = script_file 
# $2 = codine_job_id
# $3 = req_name
# $4 = std_err_out
# $5 = s_cpu
# $6 = s_rss
# $7 = script_args
# $8 = qsub_args
# $9 = s_flag

out=/tmp/qstd_debug
date=`date`
touch $out
echo "$date Qsub called:" >> $out
echo "script_file:   $1" >> $out
echo "codine_job_id: $2" >> $out
echo "req_name:      $3" >> $out
echo "std_err_out:   $4" >> $out
echo "s_cpu:         $5" >> $out
echo "s_rss:         $6" >> $out
echo "script_args:   $7" >> $out
echo "qsub_args:     $8" >> $out
echo "s_flag:        $9" >> $out

if [ "x$CODINE_ROOT" = "x" ]; then
   CODINE_ROOT=/usr/CODINE
fi

ARC=`$CODINE_ROOT/util/arch`
QSUB=$CODINE_ROOT/bin/$ARC/qsub
unset COD_DEBUG_LEVEL

script_file=$1 
codine_job_id=$2 
req_name=$3 
std_err_out=$4 
s_cpu=$5 
s_rss=$6 
script_args=$7 
qsub_args=$8 
s_flag=$9 

# do some checks
if [ ! -r $script_file ]; then
   echo "$0: script file $script_file is not readable" >> $out
   exit 1
fi
if [ ! -x $QSUB ]; then
   echo "$0: $QSUB is not executable" >> $out
   exit 1
fi

# build qsub options
qsub_opt=
# pass shell request
if [ "$s_flag" != "" ]; then
   qsub_opt="$qsub_opt -S $s_flag"
fi
# pass job name 
if [ "$s_cpu" != "" ]; then
   qsub_opt="$qsub_opt -N $req_name"
fi

# prevent recursive call of this script 
# by requesting non-tranfer queue
# recursion_stopper="-l a=linux"

foreign_jobid=`$QSUB $qsub_opt $recursion_stopper $script_file | cut -f3 -d" "`
if [ $? -ne 0 ]; then
   echo "$0: submit failure" >> $out
   exit 1
fi

echo $foreign_jobid

exit 0
