#!/bin/sh
#
# (c) 2000 Sun Microsystems, Inc.
#

# put a call to this script into commands.<qs> then it will be
# called by qstd on job finish 
# parameters 
# $1 = codine_job_id 
# $2 = std_err_out
# $3 = std_out
# $4 = std_err
# $5 = submitdir
# $6 = script_name
#
# codine_job_id:
#   Job identification number CODINE uses. The CODINE qsub command returns
#   this number to the caller of qsub.
#
# std_err_out:
#   mixed stderr/out output of job - in case of -eo flag
#
# std_out:
#   stdout of job
#
# std_err:
#   stderr of job
#
# submitdir:
#  if no (qsub) -cwd flag is specified submitdir = "" else 
#  submitdir contains the directory in which qsub was called on submithost
#
# script_name:
#  the name of the jobscript as submitted.


###############
# SHELL PROCS
###############

# set output filename
#    arg1 = outputdirectory ( if -cwd ; else $HOME )
#    arg2 = filename
#    
#    if arg2 = absolute_path ==> output filename = arg2
SetFName()
{
	# quick return if possible --> nothing's set
	if [ "$2" = "" ]; then
		echo ""
		return 0
	fi

	# is first char a '/' ? if so return arg2
	if [ `expr index $2 //` = 1 ]; then
		echo $2
		return 0
	fi

	# concatenate and return $2/$1
	echo $1/$2
	return 0
}



#############
# MAIN
#############

# set PATH - better safe than sorry
PATH=/bin:/usr/bin:/usr/bsd:/usr/etc:$PATH
export PATH

# set host that we conect to via rsh
QSI_MACHINE=hosti

# remove script and environment script on QSI_MACHINE
rsh $QSI_MACHINE rm script.$1 env_script.$1

# if submitdir = "" --> OUTDIR = $HOME
if [ "$5" = "" ]; then
	OUTDIR=$HOME
else
	OUTDIR=$5
fi

# set output files
if [ "$2" != "" ]; then
	# set F in case of -eo flag
	F=`SetFName $OUTDIR $2`
else
	# set FOUT/FERR otherwise
	# if none is specified use CODINE defaults
	if [ "$3" = "" ]; then
		FTMP=`expr substr $6 1 7`.o$1
		FOUT=`SetFName $OUTDIR $FTMP`
	else
		FOUT=`SetFName $OUTDIR $3`
	fi
	if [ "$4" = "" ]; then
		FTMP=`expr substr $6 1 7`.e$1
		FERR=`SetFName $OUTDIR $FTMP`
	else
		FERR=`SetFName $OUTDIR $4`
	fi
fi

# retrieve output
if [ "$2" != "" ]; then
	# the -eo case
	rsh $QSI_MACHINE cat errout.$1 >> $F
	rsh $QSI_MACHINE rm errout.$1
else
	# separate stdout/err
	rsh $QSI_MACHINE cat output.$1 >> $FOUT
	rsh $QSI_MACHINE cat error.$1 >> $FERR
	rsh $QSI_MACHINE rm output.$1
	rsh $QSI_MACHINE rm error.$1
fi

exit 0
